@@ -17,36 +17,45 @@
 
 */
 
-#ifndef ODSEXCEPTION_H
-#define ODSEXCEPTION_H
+#pragma once
 
-#include <exception>
-#include <string>
-#include <QString>
+#include <QException>
+#include <QDebug>
 
-class OdsException : public std::exception
+class OdsException : public QException
 {
   public:
-  OdsException(QString message) throw()
+  OdsException(const QString &message) throw()
   {
-    _message = message;
+    qDebug() << message;
+    m_message = message;
   }
 
-  /*mcqError(std::string message = "") throw () :
-    _message(message.c_str()) {
-    }*/
-
-
-  virtual const char *
-  what() const throw() override
+  OdsException(const OdsException &other) throw()
   {
-    return _message.toStdString().c_str();
+    m_message = other.m_message;
+  }
+  void
+  raise() const override
+  {
+    throw *this;
+  }
+  virtual QException *
+  clone() const override
+  {
+    return new OdsException(*this);
   }
 
   virtual const QString &
   qwhat() const throw()
   {
-    return _message;
+    return m_message;
+  }
+
+  virtual const char *
+  what() const throw() override
+  {
+    return m_message.toStdString().c_str();
   }
 
   virtual ~OdsException() throw()
@@ -54,7 +63,5 @@ class OdsException : public std::exception
   }
 
   private:
-  QString _message; // Description de l'erreur
+  QString m_message; // Description of the error
 };
-
-#endif // ODSEXCEPTION_H
