@@ -197,6 +197,11 @@ TsvDirectoryWriter::writeEmptyCell()
   _startingSheet = false;
 }
 void
+TsvDirectoryWriter::writeCell(std::size_t num)
+{
+  writeCell(QString::number(num, 'g', 10));
+}
+void
 TsvDirectoryWriter::writeCell(int num)
 {
   writeRawCell(QString::number(num, 'g', 10));
@@ -240,7 +245,7 @@ TsvDirectoryWriter::writeCell(const QDateTime &date)
   writeRawCell(date.toString("yyyy-MM-ddThh:mm:ss"));
 }
 void
-TsvDirectoryWriter::writeCell(const QUrl &url, const QString &text)
+TsvDirectoryWriter::writeCell([[maybe_unused ]] const QUrl &url, const QString &text)
 {
   writeCell(text);
 }
